%define is_rhel 0%{?rhel} != 0

# python3 is not available on RHEL <=7
%if %{is_rhel} && 0%{?rhel} <= 7
# disable python3 by default
%bcond_with python3
%else
%bcond_without python3
%endif

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif

Summary:  A python module for system storage configuration
Name: python-blivet
Url: https://storageapis.wordpress.com/projects/blivet
Version: 3.2.1

#%%global prerelease .b2
# prerelease, if defined, should be something like .a1, .b1, .b2.dev1, or .c2
Release: 1%{?prerelease}%{?dist}
Epoch: 1000
License: LGPLv2+
%global realname blivet
%global realversion %{version}%{?prerelease}
Source0: https://github.com/storaged-project/blivet/archive/%{realname}-%{realversion}.tar.gz
Source1: https://github.com/storaged-project/blivet/archive/%{realname}-%{realversion}-tests.tar.gz
Patch0: 0001-Double-recommended-LVM-thin-pool-metadata-space.patch
Patch1: 0001-Create-any-XFS-filesystems-with-reflink-support.patch

# Versions of required components (done so we make sure the buildrequires
# match the requires versions of things).
%global partedver 1.8.1
%global pypartedver 3.10.4
%global utillinuxver 2.15.1
%global libblockdevver 2.19
%global libbytesizever 0.3
%global pyudevver 0.18

BuildArch: noarch

%description
The python-blivet package is a python module for examining and modifying
storage configuration.

%package -n %{realname}-data
Summary: Data for the %{realname} python module.

BuildRequires: systemd

Conflicts: python-blivet < 1:2.0.0
Conflicts: python3-blivet < 1:2.0.0

%description -n %{realname}-data
The %{realname}-data package provides data files required by the %{realname}
python module.

%if %{with python3}
%package -n python3-%{realname}
Summary: A python3 package for examining and modifying storage configuration.

%{?python_provide:%python_provide python3-%{realname}}

BuildRequires: gettext
BuildRequires: python3-devel
BuildRequires: python3-setuptools

Requires: python3
Requires: python3-six
Requires: python3-pyudev >= %{pyudevver}
Requires: parted >= %{partedver}
Requires: python3-pyparted >= %{pypartedver}
Requires: libselinux-python3
Requires: python3-blockdev >= %{libblockdevver}
Recommends: libblockdev-btrfs >= %{libblockdevver}
Recommends: libblockdev-crypto >= %{libblockdevver}
Recommends: libblockdev-dm >= %{libblockdevver}
Recommends: libblockdev-fs >= %{libblockdevver}
Recommends: libblockdev-kbd >= %{libblockdevver}
Recommends: libblockdev-loop >= %{libblockdevver}
Recommends: libblockdev-lvm >= %{libblockdevver}
Recommends: libblockdev-mdraid >= %{libblockdevver}
Recommends: libblockdev-mpath >= %{libblockdevver}
Recommends: libblockdev-nvdimm >= %{libblockdevver}
Recommends: libblockdev-part >= %{libblockdevver}
Recommends: libblockdev-swap >= %{libblockdevver}
Recommends: libblockdev-s390 >= %{libblockdevver}
Requires: python3-bytesize >= %{libbytesizever}
Requires: util-linux >= %{utillinuxver}
Requires: lsof
Requires: python3-gobject-base
Requires: systemd-udev
Requires: %{realname}-data = %{epoch}:%{version}-%{release}

Obsoletes: blivet-data < 1:2.0.0

%if %{without python2}
Obsoletes: python2-blivet < 1:2.0.2-2
Obsoletes: python-blivet < 1:2.0.2-2
%else
Obsoletes: python-blivet < 1:2.0.0
%endif

%description -n python3-%{realname}
The python3-%{realname} is a python3 package for examining and modifying storage
configuration.
%endif

%if %{with python2}
%package -n python2-%{realname}
Summary: A python2 package for examining and modifying storage configuration.

%{?python_provide:%python_provide python2-%{realname}}

BuildRequires: gettext
BuildRequires: python2-devel
BuildRequires: python2-setuptools

Requires: python2
Requires: python2-six
Requires: python2-pyudev >= %{pyudevver}
Requires: parted >= %{partedver}
Requires: python2-pyparted >= %{pypartedver}
Requires: python2-libselinux
Requires: python2-blockdev >= %{libblockdevver}
Recommends: libblockdev-btrfs >= %{libblockdevver}
Recommends: libblockdev-crypto >= %{libblockdevver}
Recommends: libblockdev-dm >= %{libblockdevver}
Recommends: libblockdev-fs >= %{libblockdevver}
Recommends: libblockdev-kbd >= %{libblockdevver}
Recommends: libblockdev-loop >= %{libblockdevver}
Recommends: libblockdev-lvm >= %{libblockdevver}
Recommends: libblockdev-mdraid >= %{libblockdevver}
Recommends: libblockdev-mpath >= %{libblockdevver}
Recommends: libblockdev-nvdimm >= %{libblockdevver}
Recommends: libblockdev-part >= %{libblockdevver}
Recommends: libblockdev-swap >= %{libblockdevver}
Recommends: libblockdev-s390 >= %{libblockdevver}
Requires: python2-bytesize >= %{libbytesizever}
Requires: util-linux >= %{utillinuxver}
Requires: lsof
Requires: python2-hawkey
Requires: %{realname}-data = %{epoch}:%{version}-%{release}

Requires: systemd-udev
Requires: python2-gobject-base

Obsoletes: blivet-data < 1:2.0.0
Obsoletes: python-blivet < 1:2.0.0

%description -n python2-%{realname}
The python2-%{realname} is a python2 package for examining and modifying storage
configuration.
%endif

%prep
%autosetup -n %{realname}-%{realversion} -N
%autosetup -n %{realname}-%{realversion} -b1 -p1

%build
%{?with_python2:make PYTHON=%{__python2}}
%{?with_python3:make PYTHON=%{__python3}}

%install
%{?with_python2:make PYTHON=%{__python2} DESTDIR=%{buildroot} install}
%{?with_python3:make PYTHON=%{__python3} DESTDIR=%{buildroot} install}

%find_lang %{realname}

%files -n %{realname}-data -f %{realname}.lang
%{_sysconfdir}/dbus-1/system.d/*
%{_datadir}/dbus-1/system-services/*
%{_libexecdir}/*
%{_unitdir}/*

%if %{with python2}
%files -n python2-%{realname}
%license COPYING
%doc README ChangeLog examples
%{python2_sitelib}/*
%endif

%if %{with python3}
%files -n python3-%{realname}
%license COPYING
%doc README ChangeLog examples
%{python3_sitelib}/*
%endif

%changelog
* Sun May 17 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-blivet

* Sun May 17 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 84403c4
- Update .travis.yml

* Fri Apr 10 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3599e8c
- Update to blivet-3.2.1

* Thu Feb 27 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 50cee02
- update-sources: add warning about fetching sources

* Mon Feb 17 2020 Rusty Bird <rustybird@net-c.com> - 7468b1c
- http -> https

* Fri Feb 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f1403fb
- Fix badly removed BUILDER_DIR and SRC_DIR

* Fri Feb 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6f69f9d
- get-sources: use Qubes repository

* Thu Feb 13 2020 Rusty Bird <rustybird@net-c.com> - 717189e
- Remove orphaned 0001-force-lvm-plugin.patch

* Thu Feb 13 2020 Rusty Bird <rustybird@net-c.com> - 5cbef8a
- Add XFS reflink patch

* Mon Feb 10 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 551ed03
- Update to blivet-3.1.7

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 72b1654
- travis: switch to dom0 Fedora 31

* Fri Nov 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - df4a80a
- Fix path to get_sources_from_srpm script

* Fri Nov 29 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 95eaf8b
- Update to version 3.1.6

* Fri Nov 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 933b35e
- Double default LVM thin pool metadata size

* Fri Nov 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5141cbf
- Update to blivet-3.1.5

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 36d7ec9
- travis: switch to bionic

* Sat Mar 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 614372a
- travis: initial

* Fri Jan 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f5b29a8
- Update to blivet-3.1.1

* Fri Jan 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6945eb0
- Initial commit

